import mathematics.number_theory.primes as p
from mathematics import lists


def grow_prime(stop):
    primes = lists.primes.read()
    if len(primes) == 0:
        primes = [2]
    if primes[-1] > stop:
        return
    for i in range(primes[-1] + 1, stop):
        if p.is_prime(i):
            primes.append(i)
    lists.primes.modify(primes)
    lists.primes.save()



"""Holds a list, so it can be accessed when python quits"""
import os
import platform
import mathematics


class HoldList:
    """
    Holds a list, so it can be accessed after python quits and starts again.
    """

    def __init__(self, name):
        """
        :param name: The name of the file, starts in the default directory
        """
        self.file_name = name
        try:
            if platform.system() == "Windows":
                self.path = (
                        "C:/Users/"
                        + str(os.getlogin())
                        + "/AppData/Local/Temp/mathematics-python/"
                        + mathematics.VERSION
                        + "/"
                )
            elif platform.system() == "Darwin":
                self.path = (
                        "~/Library/Application Support/mathematics-python/"
                        + mathematics.VERSION
                        + "/"
                )
            elif platform.system() == "Linux":
                self.path = "~/.mathematics-python/" + mathematics.VERSION + "/"
            else:
                self.path = ""
            self.read()
        except FileNotFoundError:
            self.hold = ""
            self.save()

    def delete(self):
        """Deletes the object, should be used with del"""
        import os

        os.remove(self.path + self.file_name + ".list")

    def save(self):
        """Saves hold"""
        to_write = str(self.hold).replace(" ", "")
        f = open(self.path + self.file_name + ".list", "w")
        f.write(to_write[1: len(to_write) - 2])
        f.close()

    def read(self):
        """
        Returns the contents of the file
        :return:
        """
        self._read()
        return self.hold

    def modify(self, new):
        self.hold = new

    def _read(self):
        f = open(self.path + self.file_name + ".list", "r")
        self.hold = f.read().split(",")
        f.close()



import platform
from os import getlogin

import setuptools

MAJOR_VERSION = 0
MINOR_VERSION = 0
PATCH = 0
VERSION = str(MAJOR_VERSION) + "." + str(MINOR_VERSION) + "." + str(PATCH) + "a0.dev202211171"
FILE_VERSION = ""
primes = [2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71, 73, 79, 83, 89, 97]

if platform.system() == "Windows":
    path = "C:/Users/" + str(getlogin()) + ".mathematics/"
elif platform.system() == "Darwin":
    path = "~/Library/Application Support/mathematics-python/"
elif platform.system() == "Linux":
    path = "~/.mathematics-python/"
else:
    path = ""
# if not exists(path + "primes.list"):
# 	with open(path + "primes.list", "x") as primes_file:
# 		primes_file.write(str(primes))

with open("README.md", "r", encoding="utf-8") as readme:
    long_description = readme.read()

setuptools.setup(
    name="mathematics",
    version=VERSION,
    author="Ashwin Naren",
    author_email="arihant2math@gmail.com",
    description="A package with mathematical functions",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/arihant2math/mathematics",
    packages=["mathematics"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Natural Language :: English",
        "Intended Audience :: Developers",
    ],
    python_requires=">=3.7",
    requires=["numpy", "matplotlib"],
)



def solve(s):
    return s.solve()


def digit_sum(s):
    return s.digit_sum()


def digit_product(s):
    """
    Returns the product of the digits
    :param s:
    :return:
    """
    return s.digit_product()
